@@ -92,6 +92,7 @@ SyGpioServer::SyGpioServer(SyRouting *r,QObject *parent)
   : QObject(parent)
 {
   gpio_routing=r;
+  gpio_eth_monitor=NULL;
 
   //
   // GPI Socket
@@ -113,6 +114,40 @@ SyGpioServer::SyGpioServer(SyRouting *r,QObject *parent)
 }
 
 
+SyGpioServer::SyGpioServer(SyRouting *r,SyEthMonitor *ethmon,QObject *parent)
+  : QObject(parent)
+{
+  gpio_routing=r;
+  gpio_eth_monitor=ethmon;
+  connect(gpio_eth_monitor,SIGNAL(startedRunning()),
+	  this,SLOT(interfaceStartedData()));
+  connect(gpio_eth_monitor,SIGNAL(stoppedRunning()),
+	  this,SLOT(interfaceStoppedData()));
+
+  //
+  // GPI Socket
+  //
+  gpio_gpi_socket=new SyMcastSocket(SyMcastSocket::ReadWrite,this);
+  gpio_gpi_socket->bind(r->nicAddress(),SWITCHYARD_GPIO_GPI_PORT);
+  if(gpio_eth_monitor->isRunning()) {
+    gpio_gpi_socket->subscribe(SWITCHYARD_GPIO_ADDRESS);
+  }
+  connect(gpio_gpi_socket,SIGNAL(readyRead()),
+	  this,SLOT(gpiReadyReadData()));
+
+  //
+  // GPO Socket
+  //
+  gpio_gpo_socket=new SyMcastSocket(SyMcastSocket::ReadWrite,this);
+  gpio_gpo_socket->bind(r->nicAddress(),SWITCHYARD_GPIO_GPO_PORT);
+  if(gpio_eth_monitor->isRunning()) {
+    gpio_gpo_socket->subscribe(SWITCHYARD_GPIO_ADDRESS);
+  }
+  connect(gpio_gpo_socket,SIGNAL(readyRead()),
+	  this,SLOT(gpoReadyReadData()));
+}
+
+
 SyGpioServer::~SyGpioServer()
 {
   delete gpio_gpo_socket;
@@ -134,7 +169,6 @@ void SyGpioServer::sendGpi(int gpi,int line,bool state,bool pulse)
   data[5]=0xFF&(gpio_serial>>16);
   data[6]=0xFF&(gpio_serial>>8);
   data[7]=0xFF&gpio_serial;
-  gpio_serial++;
 
   //
   // Livewire Number
@@ -152,9 +186,21 @@ void SyGpioServer::sendGpi(int gpi,int line,bool state,bool pulse)
   //
   data[27]=0xFF&state;
 
+  //
+  // Send Packets
+  //
   gpio_gpi_socket->writeDatagram((const char *)data,28,
 				 QHostAddress(SWITCHYARD_GPIO_ADDRESS),
 				 SWITCHYARD_GPIO_GPI_PORT);
+  gpio_serial++;
+  data[4]=0xFF&(gpio_serial>>24);
+  data[5]=0xFF&(gpio_serial>>16);
+  data[6]=0xFF&(gpio_serial>>8);
+  data[7]=0xFF&gpio_serial;
+  gpio_gpi_socket->writeDatagram((const char *)data,28,
+				 QHostAddress(SWITCHYARD_GPIO_ADDRESS),
+				 SWITCHYARD_GPIO_GPI_PORT);
+  gpio_serial+=2;
 }
 
 
@@ -176,7 +222,6 @@ void SyGpioServer::sendGpo(int gpo,int line,bool state,bool pulse)
   data[5]=0xFF&(gpio_serial>>16);
   data[6]=0xFF&(gpio_serial>>8);
   data[7]=0xFF&gpio_serial;
-  gpio_serial++;
 
   //
   // Livewire Number
@@ -209,9 +254,35 @@ void SyGpioServer::sendGpo(int gpo,int line,bool state,bool pulse)
     data[27]&=~0x0A;
   }
 
+  //
+  // Send Packets
+  //
   gpio_gpo_socket->writeDatagram((const char *)data,60,
 				 QHostAddress(SWITCHYARD_GPIO_ADDRESS),
 				 SWITCHYARD_GPIO_GPO_PORT);
+  gpio_serial++;
+  data[4]=0xFF&(gpio_serial>>24);
+  data[5]=0xFF&(gpio_serial>>16);
+  data[6]=0xFF&(gpio_serial>>8);
+  data[7]=0xFF&gpio_serial;
+  gpio_gpo_socket->writeDatagram((const char *)data,60,
+				 QHostAddress(SWITCHYARD_GPIO_ADDRESS),
+				 SWITCHYARD_GPIO_GPO_PORT);
+  gpio_serial+=2;
+}
+
+
+void SyGpioServer::interfaceStartedData()
+{
+  gpio_gpi_socket->subscribe(SWITCHYARD_GPIO_ADDRESS);
+  gpio_gpo_socket->subscribe(SWITCHYARD_GPIO_ADDRESS);
+}
+
+
+void SyGpioServer::interfaceStoppedData()
+{
+  gpio_gpi_socket->unsubscribe(SWITCHYARD_GPIO_ADDRESS);
+  gpio_gpo_socket->unsubscribe(SWITCHYARD_GPIO_ADDRESS);
 }
 
 
@@ -227,7 +298,8 @@ void SyGpioServer::gpiReadyReadData()
   while((n=gpio_gpi_socket->readDatagram(data,1500,&addr,&port))>0) {
     serial=((0xFF&data[4])<<24)+((0xFF&data[5])<<16)+((0xFF&data[6])<<8)+
       (0xFF&data[7]);
-    if(gpio_src_addr_serials[addr.toIPv4Address()]!=serial) {
+    if((gpio_src_addr_serials[addr.toIPv4Address()]!=serial)&&
+       (gpio_src_addr_serials[addr.toIPv4Address()]!=(serial-1))){
       gpio_src_addr_serials[addr.toIPv4Address()]=serial;
       //
       // FIXME: Is there actually a 'pulse' component for a GPI event?
@@ -237,6 +309,7 @@ void SyGpioServer::gpiReadyReadData()
       e=new SyGpioEvent(SyGpioEvent::TypeGpi,addr,port,
 			((0xFF&data[23])<<8)+(0xFF&data[24]),
 		       0x0D-(0xff&data[25]),(data[27]&0x01)!=0,false);
+      printf("emit 1\n");
       emit gpioReceived(e);
       emit gpiReceived(e->sourceNumber(),e->line(),e->state(),e->isPulse());
       gpio_routing->setGpi(e->sourceNumber(),e->line(),e->state(),e->isPulse());
@@ -265,7 +338,8 @@ void SyGpioServer::gpoReadyReadData()
 	   ((0xFF&data[23])<<8)+(0xFF&data[24]),
 	   (const char *)addr.toString().toUtf8(),serial);
     */
-    if(gpio_src_addr_serials[addr.toIPv4Address()]!=serial) {
+    if((gpio_src_addr_serials[addr.toIPv4Address()]!=serial)&&
+       (gpio_src_addr_serials[addr.toIPv4Address()]!=(serial-1))){
       gpio_src_addr_serials[addr.toIPv4Address()]=serial;
       e=new SyGpioEvent(SyGpioEvent::TypeGpo,addr,port,
 			((0xFF&data[23])<<8)+(0xFF&data[24]),
