@@ -92,6 +92,12 @@ unsigned SyLwrpClient::id() const
 }
 
 
+SyNode *SyLwrpClient::node() const
+{
+  return lwrp_node;
+}
+
+
 QString SyLwrpClient::deviceName() const
 {
   return lwrp_device_name;
@@ -110,6 +116,18 @@ unsigned SyLwrpClient::srcSlots() const
 }
 
 
+SySource *SyLwrpClient::src(int slot) const
+{
+  return lwrp_sources.at(slot);
+}
+
+
+SyDestination *SyLwrpClient::dst(int slot) const
+{
+  return lwrp_destinations.at(slot);
+}
+
+
 unsigned SyLwrpClient::gpis() const
 {
   return lwrp_gpis.size();
@@ -580,9 +598,10 @@ void SyLwrpClient::connectionTimeoutData()
 
 void SyLwrpClient::watchdogIntervalData()
 {
+  //  fprintf(stderr,"sending watchdog\n");
+
   SendCommand("VER");
   lwrp_watchdog_retry_timer->start(SWITCHYARD_LWRP_WATCHDOG_RETRY);
-  //  fprintf(stderr,"sending watchdog\n");
 }
 
 
@@ -611,7 +630,6 @@ void SyLwrpClient::watchdogRetryData()
     delete lwrp_gpos[i];
   }
   lwrp_gpos.clear();
-  //  lwrp_connected=false;
 
   lwrp_socket=new QTcpSocket(this);
   connect(lwrp_socket,SIGNAL(connected()),this,SLOT(connectedData()));
@@ -622,8 +640,9 @@ void SyLwrpClient::watchdogRetryData()
     lwrp_connected=false;
     emit connected(lwrp_id,false);
   }
-
-  connectToHost(lwrp_host_address,lwrp_port,lwrp_password,true);
+  if(lwrp_persistent) {
+    connectToHost(lwrp_host_address,lwrp_port,lwrp_password,true);
+  }
 }
 
 
@@ -652,7 +671,7 @@ void SyLwrpClient::SendCommand(const QString &cmd)
 
 void SyLwrpClient::ProcessCommand(const QString &cmd)
 {
-  //  printf("ProcessCommand(\"%s\")\n",(const char *)cmd.toUtf8());
+  //  printf("ProcessCommand(|%s|)\n",(const char *)cmd.toUtf8());
 
   bool handled=false;
   QStringList f0=SyAString(cmd).split(" ","\"");
@@ -807,11 +826,9 @@ void SyLwrpClient::ProcessVER(const QStringList &cmds)
     }
   }
   else {  // Watchdog response
-    if(lwrp_persistent) {
-      lwrp_watchdog_retry_timer->stop();
-      lwrp_watchdog_interval_timer->start(GetWatchdogInterval());
-    }
     //    fprintf(stderr,"receiving watchdog\n");
+    lwrp_watchdog_retry_timer->stop();
+    lwrp_watchdog_interval_timer->start(GetWatchdogInterval());
   }
 }
 
@@ -988,9 +1005,7 @@ void SyLwrpClient::ProcessIP(const QStringList &cmds)
 
   if(processed) {
     lwrp_watchdog_state=true;
-    if(lwrp_persistent) {
-      lwrp_watchdog_interval_timer->start(GetWatchdogInterval());
-    }
+    lwrp_watchdog_interval_timer->start(GetWatchdogInterval());
     if(!lwrp_connected) {
       lwrp_connected=true;
       emit connected(lwrp_id,true);
