@@ -37,9 +37,12 @@ class SyLwrpClient :public QObject
   SyLwrpClient(unsigned id,QObject *parent=0);
   ~SyLwrpClient();
   unsigned id() const;
+  SyNode *node() const;
   QString deviceName() const;
   unsigned dstSlots() const;
   unsigned srcSlots() const;
+  SySource *src(int slot) const;
+  SyDestination *dst(int slot) const;
   unsigned gpis() const;
   unsigned gpos() const;
   QString hostName() const;
